@@ -29,15 +29,18 @@
 
 //*******************************************************************
 
-GtkCTreeNode *arch_raiz;
-GtkCTreeNode *arch_cabeceras;
-GtkCTreeNode *arch_fuentes;
-GtkCTreeNode *arch_otros;
+GtkTreeStore *arch_store;
+GtkTreeIter arch_raiz;
+GtkTreeIter arch_cabeceras;
+GtkTreeIter arch_fuentes;
+GtkTreeIter arch_otros;
 
 //*******************************************************************
 
+void arch_inicializar(void);
+
 void arch_crear(void);
 
-GtkCTreeNode *arch_anadir(gchar *nombre);
+void arch_anadir(gchar *nombre,GtkTreeIter *nodo);
 
 void arch_eliminar(gchar *nombre);
