@@ -44,7 +44,13 @@ void det_autodetectar(xmlDocPtr doc,gboolean crear,guint estado)
 	static gchar *programas,*tmp;
 	static gboolean error;
 	GtkWidget *ventana;
+	GtkWidget *widget;
 	gboolean aplicacion;
+	gint cont;
+	GtkWidget *ventana_inicio;
+	gchar *nombre_utf8;
+	gsize read, written;
+	GError *locale_error;
 	
 	DEBUG_MSG(->det_autodetectar);
 	total=ULTIMA_FASE_AUTODETECCION;
@@ -60,86 +66,83 @@ void det_autodetectar(xmlDocPtr doc,gboolean crear,guint estado)
 		tmp=programas;
 	}
 
-	nodo=doc->root;
+	nodo=doc->xmlRootNode;
 	if ((crear) && (estado==0)) {
 		DEBUG_MSG(creando preferencias de autodeteccion);
 		xmlNewChild(nodo,NULL,"programas",NULL);
 		xmlNewChild(nodo,NULL,"includes",NULL);
 		xmlNewChild(nodo,NULL,"librerias",NULL);
-		nodo=buscar_nodo_xml(doc->root,"includes");
-		xmlNewChild(nodo,NULL,"xml",NULL);
-		xmlNewChild(nodo,NULL,"gtk",NULL);
-		xmlNewChild(nodo,NULL,"orbit",NULL);
-		xmlNewChild(nodo,NULL,"x11",NULL);
-		xmlNewChild(nodo,NULL,"gnome",NULL);
-		xmlNewChild(nodo,NULL,"glib",NULL);
-		xmlNewChild(nodo,NULL,"gnomeui",NULL);
-		xmlNewChild(nodo,NULL,"gnorba",NULL);
-		xmlNewChild(nodo,NULL,"audiofile",NULL);
-		xmlNewChild(nodo,NULL,"esd",NULL);
-		xmlNewChild(nodo,NULL,"gmodule",NULL);
-		xmlNewChild(nodo,NULL,"imlib",NULL);
-		nodo=buscar_nodo_xml(doc->root,"librerias");
-		xmlNewChild(nodo,NULL,"xml",NULL);
-		xmlNewChild(nodo,NULL,"gtk",NULL);
-		xmlNewChild(nodo,NULL,"orbit",NULL);
-		xmlNewChild(nodo,NULL,"x11",NULL);
-		xmlNewChild(nodo,NULL,"gnome",NULL);
-		xmlNewChild(nodo,NULL,"glib",NULL);
-		xmlNewChild(nodo,NULL,"gnomeui",NULL);
-		xmlNewChild(nodo,NULL,"gnorba",NULL);
-		xmlNewChild(nodo,NULL,"audiofile",NULL);
-		xmlNewChild(nodo,NULL,"esd",NULL);
-		xmlNewChild(nodo,NULL,"gmodule",NULL);
-		xmlNewChild(nodo,NULL,"imlib",NULL);
+		nodo=buscar_nodo_xml(doc->xmlRootNode,"includes");
+		for (cont=0;cont<LTOTALES;cont++) {
+			xmlNewChild(nodo,NULL,pro_nombre_librerias_xml[cont],NULL);
+		}
+		nodo=buscar_nodo_xml(doc->xmlRootNode,"librerias");
+		for (cont=0;cont<LTOTALES;cont++) {
+			xmlNewChild(nodo,NULL,pro_nombre_librerias_xml[cont],NULL);
+		}
 		xmlNewChild(nodo,NULL,"electric_fence",NULL);
 	}
-	barra=GTK_PROGRESS_BAR(lookup_widget(ventana_inicio,"progreso_barra_autodetect"));
-	
+	barra=GTK_PROGRESS_BAR(glade_xml_get_widget(autodetect_ventana,"progreso_barra_autodetect"));
+
 	switch (estado) {
 		case 0:
 			ejecutables.which=FALSE;
 			ejecutables.which=det_prog("which which 2>/dev/stdout");
 			break;
-		case 1:
+		case 1+LGTK2:
+		case 1+LGOBJECT2:
+		case 1+LGLIB2:
+		case 1+LGMODULE2:
+		case 1+LGTHREAD2:
+		case 1+LESD:
+		case 1+LAUDIOFILE:
+		case 1+LXML2:
+		case 1+LGNOME2:
+		case 1+LGNOMEUI2:
+		case 1+LBONOBO2:
+		case 1+LBONOBOUI2:
+		case 1+LBONOBO_ACTIVATION2:
+		case 1+LGNOMEPRINT2:
+		case 1+LGNOMEPRINTUI2:
+		case 1+LGNOME_MIME_DATA2:
+		case 1+LPANGO:
+		case 1+LPANGOXFT:
+		case 1+LPANGOFT2:
+		case 1+LGNOME_VFS2:
+		case 1+LGNOME_VFS_MODULE2:
+		case 1+LORBIT2:
+		case 1+LORBIT_COSNAMING2:
+		case 1+LLINC:
+		case 1+LGDK2:
+		case 1+LGDK_X112:
+		case 1+LGDK_PIXBUF2:
+		case 1+LGDK_PIXBUF_XLIB2:
+		case 1+LATK:
+		case 1+LGCONF2:
+		case 1+LGNOMECANVAS2:
+		case 1+LLIBART2:
+		case 1+LLIBGLADE2:
+		case 1+LGTK_X112:
+		case 1+LIMLIB:
+		case 1+LIMLIBGDK:
+		case 1+LPANGOX:
 			aplicacion=FALSE;
-			nodo=buscar_nodo_xml(doc->root,"includes");
-			nodo=buscar_nodo_xml(nodo,"xml");
-			detectado=g_strdup("`xml-config --cflags`");
+			nodo=buscar_nodo_xml(doc->xmlRootNode,"includes");
+			nodo=buscar_nodo_xml(nodo,pro_nombre_librerias_xml[estado-1]);
+			detectado=g_strdup_printf("`pkg-config %s --cflags`",pro_nombre_librerias[estado-1]);
 			break;
-		case 2:
+		case 1+LX11:
 			aplicacion=FALSE;
-			nodo=buscar_nodo_xml(doc->root,"includes");
-			nodo=buscar_nodo_xml(nodo,"gtk");
-#ifdef _LINUX
-			detectado=g_strdup("`gtk-config --cflags gtk`");
-#endif
-#ifdef _FREEBSD
-			detectado=g_strdup("`gtk12-config --cflags gtk`");
-#endif
-			break;
-		case 3:
-			aplicacion=FALSE;
-			nodo=buscar_nodo_xml(doc->root,"includes");
-			nodo=buscar_nodo_xml(nodo,"orbit");
-			if (preferencias.inc_orbit!=NULL) {
-				nombre=g_strdup_printf("%s/orbit.h",&(preferencias.inc_orbit[2]));
+			nodo=buscar_nodo_xml(doc->xmlRootNode,"includes");
+			nodo=buscar_nodo_xml(nodo,pro_nombre_librerias_xml[LX11]);
+			if (preferencias.inc[LX11]!=NULL) {
+				nombre=g_strdup_printf("%s/X.h",&(preferencias.inc[LX11][2]));
 			}
-			archivo=fopen(nombre,"r");
-			if (archivo==NULL) {
-				DEBUG_MSG(no se encontro orbit.h);
-				detectado=det_inc("orbit.h");
-			} else {
-				fclose(archivo);
-				detectado=g_strdup(preferencias.inc_orbit);
-			}
-			break;
-		case 4:
-			aplicacion=FALSE;
-			nodo=buscar_nodo_xml(doc->root,"includes");
-			nodo=buscar_nodo_xml(nodo,"x11");
-			if (preferencias.inc_x11!=NULL) {
-				nombre=g_strdup_printf("%s/X.h",&(preferencias.inc_x11[2]));
+			if (nombre != NULL) {
+				nombre_utf8 = g_strdup(nombre);
+				g_free(nombre);
+				nombre = g_locale_from_utf8(nombre_utf8, -1, &read, &written, &locale_error);
+				g_free(nombre_utf8);
 			}
 			archivo=fopen(nombre,"r");
 			if (archivo==NULL) {
@@ -147,96 +150,69 @@ void det_autodetectar(xmlDocPtr doc,gboolean crear,guint estado)
 				detectado=det_inc("X.h");
 			} else {
 				fclose(archivo);
-				detectado=g_strdup(preferencias.inc_x11);
+				detectado=g_strdup(preferencias.inc[LX11]);
 			}
 			break;
-		case 5:
+		case 1+LGETTEXT:
 			aplicacion=FALSE;
-			nodo=buscar_nodo_xml(doc->root,"includes");
-			nodo=buscar_nodo_xml(nodo,"gnome");
-			detectado=g_strdup("`gnome-config --cflags gnome`");
+			nodo=buscar_nodo_xml(doc->xmlRootNode,"includes");
+			nodo=buscar_nodo_xml(nodo,pro_nombre_librerias_xml[estado-1]);
+			detectado=NULL;
 			break;
-		case 6:
+		case LTOTALES+1+LGTK2:
+		case LTOTALES+1+LGOBJECT2:
+		case LTOTALES+1+LGLIB2:
+		case LTOTALES+1+LGMODULE2:
+		case LTOTALES+1+LGTHREAD2:
+		case LTOTALES+1+LESD:
+		case LTOTALES+1+LAUDIOFILE:
+		case LTOTALES+1+LXML2:
+		case LTOTALES+1+LGNOME2:
+		case LTOTALES+1+LGNOMEUI2:
+		case LTOTALES+1+LBONOBO2:
+		case LTOTALES+1+LBONOBOUI2:
+		case LTOTALES+1+LBONOBO_ACTIVATION2:
+		case LTOTALES+1+LGNOMEPRINT2:
+		case LTOTALES+1+LGNOMEPRINTUI2:
+		case LTOTALES+1+LGNOME_MIME_DATA2:
+		case LTOTALES+1+LPANGO:
+		case LTOTALES+1+LPANGOXFT:
+		case LTOTALES+1+LPANGOFT2:
+		case LTOTALES+1+LGNOME_VFS2:
+		case LTOTALES+1+LGNOME_VFS_MODULE2:
+		case LTOTALES+1+LORBIT2:
+		case LTOTALES+1+LORBIT_COSNAMING2:
+		case LTOTALES+1+LLINC:
+		case LTOTALES+1+LGDK2:
+		case LTOTALES+1+LGDK_X112:
+		case LTOTALES+1+LGDK_PIXBUF2:
+		case LTOTALES+1+LGDK_PIXBUF_XLIB2:
+		case LTOTALES+1+LATK:
+		case LTOTALES+1+LGCONF2:
+		case LTOTALES+1+LGNOMECANVAS2:
+		case LTOTALES+1+LLIBART2:
+		case LTOTALES+1+LLIBGLADE2:
+		case LTOTALES+1+LGTK_X112:
+		case LTOTALES+1+LIMLIB:
+		case LTOTALES+1+LIMLIBGDK:
+		case LTOTALES+1+LPANGOX:
 			aplicacion=FALSE;
-			nodo=buscar_nodo_xml(doc->root,"includes");
-			nodo=buscar_nodo_xml(nodo,"gnomeui");
-			detectado=g_strdup("`gnome-config --cflags gnomeui`");
+			nodo=buscar_nodo_xml(doc->xmlRootNode,"librerias");
+			nodo=buscar_nodo_xml(nodo,pro_nombre_librerias_xml[estado-1-LTOTALES]);
+			detectado=g_strdup_printf("`pkg-config %s --libs`",pro_nombre_librerias[estado-1-LTOTALES]);
 			break;
-		case 7:
+		case LTOTALES+1+LX11:
 			aplicacion=FALSE;
-			nodo=buscar_nodo_xml(doc->root,"includes");
-			nodo=buscar_nodo_xml(nodo,"glib");
-#ifdef _LINUX
-			detectado=g_strdup("`glib-config --cflags glib`");
-#endif
-#ifdef _FREEBSD
-			detectado=g_strdup("`glib12-config --cflags glib`");
-#endif
-			break;
-		case 8:
-			aplicacion=FALSE;
-			nodo=buscar_nodo_xml(doc->root,"includes");
-			nodo=buscar_nodo_xml(nodo,"gnorba");
-			detectado=g_strdup("`gnome-config --cflags gnorba`");
-			break;
-		case 9:
-			aplicacion=FALSE;
-			nodo=buscar_nodo_xml(doc->root,"includes");
-			nodo=buscar_nodo_xml(nodo,"audiofile");
-			detectado=g_strdup("`audiofile-config --cflags`");
-			break;
-		case 10:
-			aplicacion=FALSE;
-			nodo=buscar_nodo_xml(doc->root,"includes");
-			nodo=buscar_nodo_xml(nodo,"esd");
-			detectado=g_strdup("`esd-config --cflags`");
-			break;
-		case 11:
-			aplicacion=FALSE;
-			nodo=buscar_nodo_xml(doc->root,"includes");
-			nodo=buscar_nodo_xml(nodo,"gmodule");
-#ifdef _LINUX
-			detectado=g_strdup("`glib-config --cflags gmodule`");
-#endif
-#ifdef _FREEBSD
-			detectado=g_strdup("`glib12-config --cflags gmodule`");
-#endif
-			break;
-		case 12:
-			aplicacion=FALSE;
-			nodo=buscar_nodo_xml(doc->root,"includes");
-			nodo=buscar_nodo_xml(nodo,"imlib");
-			detectado=g_strdup("`imlib-config --cflags`");
-			break;
-		case 13:
-			aplicacion=FALSE;
-			nodo=buscar_nodo_xml(doc->root,"librerias");
-			nodo=buscar_nodo_xml(nodo,"xml");
-			detectado=g_strdup("`xml-config --libs`");
-			break;
-		case 14:
-			aplicacion=FALSE;
-			nodo=buscar_nodo_xml(doc->root,"librerias");
-			nodo=buscar_nodo_xml(nodo,"gtk");
-#ifdef _LINUX
-			detectado=g_strdup("`gtk-config --libs gtk`");
-#endif
-#ifdef _FREEBSD
-			detectado=g_strdup("`gtk12-config --libs gtk`");
-#endif
-			break;
-		case 15:
-			aplicacion=FALSE;
-			nodo=buscar_nodo_xml(doc->root,"librerias");
-			nodo=buscar_nodo_xml(nodo,"orbit");
-			detectado=g_strdup("`orbit-config --libs client` `orbit-config --libs server`");
-			break;
-		case 16:
-			aplicacion=FALSE;
-			nodo=buscar_nodo_xml(doc->root,"librerias");
-			nodo=buscar_nodo_xml(nodo,"x11");
-			if (preferencias.lib_x11!=NULL) {
-				nombre=g_strdup_printf("%s/libX11.so",&(preferencias.lib_x11[2]));
+			nodo=buscar_nodo_xml(doc->xmlRootNode,"librerias");
+			nodo=buscar_nodo_xml(nodo,pro_nombre_librerias_xml[LX11]);
+			if (preferencias.lib[LX11]!=NULL) {
+				nombre=g_strdup_printf("%s/libX11.so",&(preferencias.lib[LX11][2]));
+			}
+			if (nombre != NULL) {
+				nombre_utf8 = g_strdup(nombre);
+				g_free(nombre);
+				nombre = g_locale_from_utf8(nombre_utf8, -1, &read, &written, &locale_error);
+				g_free(nombre_utf8);
 			}
 			archivo=fopen(nombre,"r");
 			if (archivo==NULL) {
@@ -244,74 +220,28 @@ void det_autodetectar(xmlDocPtr doc,gboolean crear,guint estado)
 				detectado=det_lib("libX11.so");
 			} else {
 				fclose(archivo);
-				detectado=g_strdup(preferencias.lib_x11);
+				detectado=g_strdup(preferencias.lib[LX11]);
 			}
 			break;
-		case 17:
+		case LTOTALES+1+LGETTEXT:
 			aplicacion=FALSE;
-			nodo=buscar_nodo_xml(doc->root,"librerias");
-			nodo=buscar_nodo_xml(nodo,"gnome");
-			detectado=g_strdup("`gnome-config --libs gnome`");
+			nodo=buscar_nodo_xml(doc->xmlRootNode,"librerias");
+			nodo=buscar_nodo_xml(nodo,pro_nombre_librerias_xml[estado-1-LTOTALES]);
+			detectado=NULL;
 			break;
-		case 18:
+		case LTOTALES+LTOTALES+1:
 			aplicacion=FALSE;
-			nodo=buscar_nodo_xml(doc->root,"librerias");
-			nodo=buscar_nodo_xml(nodo,"glib");
-#ifdef _LINUX
-			detectado=g_strdup("`glib-config --libs glib`");
-#endif
-#ifdef _FREEBSD
-			detectado=g_strdup("`glib12-config --libs glib`");
-#endif
-			break;
-		case 19:
-			aplicacion=FALSE;
-			nodo=buscar_nodo_xml(doc->root,"librerias");
-			nodo=buscar_nodo_xml(nodo,"gnomeui");
-			detectado=g_strdup("`gnome-config --libs gnomeui`");
-			break;
-		case 20:
-			aplicacion=FALSE;
-			nodo=buscar_nodo_xml(doc->root,"librerias");
-			nodo=buscar_nodo_xml(nodo,"gnorba");
-			detectado=g_strdup("`gnome-config --libs gnorba`");
-			break;
-		case 21:
-			aplicacion=FALSE;
-			nodo=buscar_nodo_xml(doc->root,"librerias");
-			nodo=buscar_nodo_xml(nodo,"audiofile");
-			detectado=g_strdup("`audiofile-config --libs`");
-			break;
-		case 22:
-			aplicacion=FALSE;
-			nodo=buscar_nodo_xml(doc->root,"librerias");
-			nodo=buscar_nodo_xml(nodo,"esd");
-			detectado=g_strdup("`esd-config --libs`");
-			break;
-		case 23:
-			aplicacion=FALSE;
-			nodo=buscar_nodo_xml(doc->root,"librerias");
-			nodo=buscar_nodo_xml(nodo,"gmodule");
-#ifdef _LINUX
-			detectado=g_strdup("`glib-config --libs gmodule`");
-#endif
-#ifdef _FREEBSD
-			detectado=g_strdup("`glib12-config --libs gmodule`");
-#endif
-			break;
-		case 24:
-			aplicacion=FALSE;
-			nodo=buscar_nodo_xml(doc->root,"librerias");
-			nodo=buscar_nodo_xml(nodo,"imlib");
-			detectado=g_strdup("`imlib-config --libs`");
-			break;
-		case 25:
-			aplicacion=FALSE;
-			nodo=buscar_nodo_xml(doc->root,"librerias");
+			nodo=buscar_nodo_xml(doc->xmlRootNode,"librerias");
 			nodo=buscar_nodo_xml(nodo,"electric_fence");
 			if (preferencias.lib_electric_fence!=NULL) {
 				nombre=g_strdup_printf("%s/libefence.so",&(preferencias.lib_electric_fence[2]));
 			}
+			if (nombre != NULL) {
+				nombre_utf8 = g_strdup(nombre);
+				g_free(nombre);
+				nombre = g_locale_from_utf8(nombre_utf8, -1, &read, &written, &locale_error);
+				g_free(nombre_utf8);
+			}
 			archivo=fopen(nombre,"r");
 			if (archivo==NULL) {
 				DEBUG_MSG(no se encontro libefence.so);
@@ -321,9 +251,9 @@ void det_autodetectar(xmlDocPtr doc,gboolean crear,guint estado)
 				detectado=g_strdup(preferencias.lib_electric_fence);
 			}
 			break;
-		case 26:
+		case LTOTALES+LTOTALES+2:
 			aplicacion=TRUE;
-			nodo=buscar_nodo_xml(doc->root,"programas");
+			nodo=buscar_nodo_xml(doc->xmlRootNode,"programas");
 			DEBUG_MSG(buscando gcc);
 			if (det_prog("gcc --version 2> /dev/stdout")) {
 				xmlSetProp(nodo,"gcc","1");
@@ -333,19 +263,11 @@ void det_autodetectar(xmlDocPtr doc,gboolean crear,guint estado)
 				ejecutables.gcc=FALSE;
 			}
 			break;
-		case 27:
+		case LTOTALES+LTOTALES+3:
 			aplicacion=TRUE;
-			nodo=buscar_nodo_xml(doc->root,"programas");
+			nodo=buscar_nodo_xml(doc->xmlRootNode,"programas");
 			DEBUG_MSG(buscando make);
-#ifdef _NETBSD
-			if (det_prog("gmake --version 2> /dev/stdout")) {
-#endif
-#ifdef _FREEBSD
-			if (det_prog("gmake --version 2> /dev/stdout")) {
-#endif
-#ifdef _LINUX
 			if (det_prog("make --version 2> /dev/stdout")) {
-#endif
 				xmlSetProp(nodo,"make","1");
 				ejecutables.make=TRUE;
 			} else {
@@ -353,9 +275,9 @@ void det_autodetectar(xmlDocPtr doc,gboolean crear,guint estado)
 				ejecutables.make=FALSE;
 			}
 			break;
-		case 28:
+		case LTOTALES+LTOTALES+4:
 			aplicacion=TRUE;
-			nodo=buscar_nodo_xml(doc->root,"programas");
+			nodo=buscar_nodo_xml(doc->xmlRootNode,"programas");
 			DEBUG_MSG(buscando aclocal);
 			if (det_prog("aclocal --version 2> /dev/stdout")) {
 				xmlSetProp(nodo,"aclocal","1");
@@ -369,9 +291,9 @@ void det_autodetectar(xmlDocPtr doc,gboolean crear,guint estado)
 				error=TRUE;
 			}
 			break;
-		case 29:
+		case LTOTALES+LTOTALES+5:
 			aplicacion=TRUE;
-			nodo=buscar_nodo_xml(doc->root,"programas");
+			nodo=buscar_nodo_xml(doc->xmlRootNode,"programas");
 			DEBUG_MSG(buscando automake);
 			if (det_prog("automake --version 2> /dev/stdout")) {
 				xmlSetProp(nodo,"automake","1");
@@ -385,9 +307,9 @@ void det_autodetectar(xmlDocPtr doc,gboolean crear,guint estado)
 				error=TRUE;
 			}
 			break;
-		case 30:
+		case LTOTALES+LTOTALES+6:
 			aplicacion=TRUE;
-			nodo=buscar_nodo_xml(doc->root,"programas");
+			nodo=buscar_nodo_xml(doc->xmlRootNode,"programas");
 			DEBUG_MSG(buscando autoconf);
 			if (det_prog("autoconf --version 2> /dev/stdout")) {
 				xmlSetProp(nodo,"autoconf","1");
@@ -401,11 +323,11 @@ void det_autodetectar(xmlDocPtr doc,gboolean crear,guint estado)
 				error=TRUE;
 			}
 			break;
-		case 31:
+		case LTOTALES+LTOTALES+7:
 			aplicacion=TRUE;
-			nodo=buscar_nodo_xml(doc->root,"programas");
+			nodo=buscar_nodo_xml(doc->xmlRootNode,"programas");
 			DEBUG_MSG(buscando glade);
-			if (det_prog("glade --version 2> /dev/stdout")) {
+			if (det_prog("glade-2 --version 2> /dev/stdout")) {
 				xmlSetProp(nodo,"glade","1");
 				ejecutables.glade=TRUE;
 			} else {
@@ -413,17 +335,12 @@ void det_autodetectar(xmlDocPtr doc,gboolean crear,guint estado)
 				ejecutables.glade=FALSE;
 			}
 			break;
-		case 32:
+		case LTOTALES+LTOTALES+8:
 			aplicacion=TRUE;
-			nodo=buscar_nodo_xml(doc->root,"programas");
+			nodo=buscar_nodo_xml(doc->xmlRootNode,"programas");
 			DEBUG_MSG(buscando exuberant-ctags);
-			//the executable could be called ctags-exuberant or just ctags, depending on the distro
-#ifdef _LINUX
+			//The executable could be called ctags-exuberant or just ctags, depending on the distribution used.
 			if (det_prog("ctags-exuberant --version 2> /dev/stdout")) {
-#endif
-#ifdef _FREEBSD
-			if (det_prog("exctags --version 2> /dev/stdout")) {
-#endif
 				xmlSetProp(nodo,"ctags","1");
 				ejecutables.ctags=TRUE;
 			} else if (det_prog("ctags --version 2> /dev/stdout")) {
@@ -438,9 +355,9 @@ void det_autodetectar(xmlDocPtr doc,gboolean crear,guint estado)
 				error=TRUE;
 			}
 			break;
-		case 33:
+		case LTOTALES+LTOTALES+9:
 			aplicacion=TRUE;
-			nodo=buscar_nodo_xml(doc->root,"programas");
+			nodo=buscar_nodo_xml(doc->xmlRootNode,"programas");
 			DEBUG_MSG(buscando autoheader);
 			if (det_prog("autoheader --version 2> /dev/stdout")) {
 				xmlSetProp(nodo,"autoheader","1");
@@ -454,9 +371,9 @@ void det_autodetectar(xmlDocPtr doc,gboolean crear,guint estado)
 				error=TRUE;
 			}
 			break;
-		case 34:
+		case LTOTALES+LTOTALES+10:
 			aplicacion=TRUE;
-			nodo=buscar_nodo_xml(doc->root,"programas");
+			nodo=buscar_nodo_xml(doc->xmlRootNode,"programas");
 			DEBUG_MSG(buscando lpr);
 			if (det_prog("lpr --version 2> /dev/stdout")) {
 				xmlSetProp(nodo,"lpr","1");
@@ -466,141 +383,25 @@ void det_autodetectar(xmlDocPtr doc,gboolean crear,guint estado)
 				ejecutables.lpr=FALSE;
 			}
 			break;
-		case 35:
+		case LTOTALES+LTOTALES+11:
 			aplicacion=TRUE;
-			nodo=buscar_nodo_xml(doc->root,"programas");
-			DEBUG_MSG(buscando glib);
-#ifdef _LINUX
-			if (det_prog("glib-config --version 2> /dev/stdout")) {
-#endif
-#ifdef _FREEBSD
-			if (det_prog("glib12-config --version 2> /dev/stdout")) {
-#endif
-				xmlSetProp(nodo,"glib-config","1");
-				ejecutables.glib_config=TRUE;
+			nodo=buscar_nodo_xml(doc->xmlRootNode,"programas");
+			DEBUG_MSG(buscando pkg-config);
+			if (det_prog("pkg-config --version 2> /dev/stdout")) {
+				xmlSetProp(nodo,"pkg-config","1");
+				ejecutables.pkg_config=TRUE;
 			} else {
-				xmlSetProp(nodo,"glib-config","0");
-				ejecutables.glib_config=FALSE;
-#ifdef _LINUX
-				programas=g_strdup_printf("%s\tglib-config\n",tmp);
-#endif
-#ifdef _FREEBSD
-				programas=g_strdup_printf("%s\tglib12-config\n",tmp);
-#endif
+				xmlSetProp(nodo,"pkg-config","0");
+				ejecutables.pkg_config=FALSE;
+				programas=g_strdup_printf("%s\tpkg-config\n",tmp);
 				g_free(tmp);
 				tmp=programas;
 				error=TRUE;
 			}
 			break;
-		case 36:
+		case LTOTALES+LTOTALES+12:
 			aplicacion=TRUE;
-			nodo=buscar_nodo_xml(doc->root,"programas");
-			DEBUG_MSG(buscando xml-config);
-			if (det_prog("xml-config --version 2> /dev/stdout")) {
-				xmlSetProp(nodo,"xml-config","1");
-				ejecutables.xml_config=TRUE;
-			} else {
-				xmlSetProp(nodo,"xml-config","0");
-				ejecutables.xml_config=FALSE;
-				programas=g_strdup_printf("%s\txml-config\n",tmp);
-				g_free(tmp);
-				tmp=programas;
-				error=TRUE;
-			}
-			break;
-		case 37:
-			aplicacion=TRUE;
-			nodo=buscar_nodo_xml(doc->root,"programas");
-			DEBUG_MSG(buscando gtk-config);
-#ifdef _LINUX
-			if (det_prog("gtk-config --version 2> /dev/stdout")) {
-#endif
-#ifdef _FREEBSD
-			if (det_prog("gtk12-config --version 2> /dev/stdout")) {
-#endif
-				xmlSetProp(nodo,"gtk-config","1");
-				ejecutables.gtk_config=TRUE;
-			} else {
-				xmlSetProp(nodo,"gtk-config","0");
-				ejecutables.gtk_config=FALSE;
-#ifdef _LINUX
-				programas=g_strdup_printf("%s\tgtk-config\n",tmp);
-#endif
-#ifdef _FREEBSD
-				programas=g_strdup_printf("%s\tgtk12-config\n",tmp);
-#endif
-				g_free(tmp);
-				tmp=programas;
-				error=TRUE;
-			}
-			break;
-		case 38:
-			aplicacion=TRUE;
-			nodo=buscar_nodo_xml(doc->root,"programas");
-			DEBUG_MSG(buscando gnome-config);
-			if (det_prog("gnome-config --version 2> /dev/stdout")) {
-				xmlSetProp(nodo,"gnome-config","1");
-				ejecutables.gnome_config=TRUE;
-			} else {
-				xmlSetProp(nodo,"gnome-config","0");
-				ejecutables.gnome_config=FALSE;
-				programas=g_strdup_printf("%s\tgnome-config\n",tmp);
-				g_free(tmp);
-				tmp=programas;
-				error=TRUE;
-			}
-			break;
-		case 39:
-			aplicacion=TRUE;
-			nodo=buscar_nodo_xml(doc->root,"programas");
-			DEBUG_MSG(buscando audiofile-config);
-			if (det_prog("audiofile-config --version 2> /dev/stdout")) {
-				xmlSetProp(nodo,"audiofile-config","1");
-				ejecutables.audiofile_config=TRUE;
-			} else {
-				xmlSetProp(nodo,"audiofile-config","0");
-				ejecutables.audiofile_config=FALSE;
-				programas=g_strdup_printf("%s\taudiofile-config\n",tmp);
-				g_free(tmp);
-				tmp=programas;
-				error=TRUE;
-			}
-			break;
-		case 40:
-			aplicacion=TRUE;
-			nodo=buscar_nodo_xml(doc->root,"programas");
-			DEBUG_MSG(buscando esd-config);
-			if (det_prog("esd-config --version 2> /dev/stdout")) {
-				xmlSetProp(nodo,"esd-config","1");
-				ejecutables.esd_config=TRUE;
-			} else {
-				xmlSetProp(nodo,"esd-config","0");
-				ejecutables.esd_config=FALSE;
-				programas=g_strdup_printf("%s\tesd-config\n",tmp);
-				g_free(tmp);
-				tmp=programas;
-				error=TRUE;
-			}
-			break;
-		case 41:
-			aplicacion=TRUE;
-			nodo=buscar_nodo_xml(doc->root,"programas");
-			DEBUG_MSG(buscando imlib-config);
-			if (det_prog("imlib-config --version 2> /dev/stdout")) {
-				xmlSetProp(nodo,"imlib-config","1");
-				ejecutables.imlib_config=TRUE;
-			} else {
-				xmlSetProp(nodo,"imlib-config","0");
-				ejecutables.imlib_config=FALSE;
-				programas=g_strdup_printf("%s\timlib-config\n",tmp);
-				g_free(tmp);
-				tmp=programas;
-				error=TRUE;
-			}
-			break;
-		case 42:
-			aplicacion=TRUE;
-			nodo=buscar_nodo_xml(doc->root,"programas");
+			nodo=buscar_nodo_xml(doc->xmlRootNode,"programas");
 			DEBUG_MSG(buscando gdb);
 			if (det_prog("gdb 2> /dev/stdout")) {
 				xmlSetProp(nodo,"gdb","1");
@@ -610,9 +411,9 @@ void det_autodetectar(xmlDocPtr doc,gboolean crear,guint estado)
 				ejecutables.gdb=FALSE;
 			}
 			break;
-		case 43:
+		case LTOTALES+LTOTALES+13:
 			aplicacion=TRUE;
-			nodo=buscar_nodo_xml(doc->root,"programas");
+			nodo=buscar_nodo_xml(doc->xmlRootNode,"programas");
 			DEBUG_MSG(buscando ddd);
 			if (det_prog("ddd --version 2> /dev/stdout")) {
 				xmlSetProp(nodo,"ddd","1");
@@ -622,9 +423,9 @@ void det_autodetectar(xmlDocPtr doc,gboolean crear,guint estado)
 				ejecutables.ddd=FALSE;
 			}
 			break;
-		case 44:
+		case LTOTALES+LTOTALES+14:
 			aplicacion=TRUE;
-			nodo=buscar_nodo_xml(doc->root,"programas");
+			nodo=buscar_nodo_xml(doc->xmlRootNode,"programas");
 			DEBUG_MSG(buscando grep);
 			if (det_prog("grep --version 2> /dev/stdout")) {
 				xmlSetProp(nodo,"grep","1");
@@ -634,9 +435,9 @@ void det_autodetectar(xmlDocPtr doc,gboolean crear,guint estado)
 				ejecutables.grep=FALSE;
 			}
 			break;
-		case 45:
+		case LTOTALES+LTOTALES+15:
 			aplicacion=TRUE;
-			nodo=buscar_nodo_xml(doc->root,"programas");
+			nodo=buscar_nodo_xml(doc->xmlRootNode,"programas");
 			if (det_prog("memprof --version 2> /dev/stdout")) {
 				xmlSetProp(nodo,"memprof","1");
 				ejecutables.memprof=TRUE;
@@ -645,9 +446,9 @@ void det_autodetectar(xmlDocPtr doc,gboolean crear,guint estado)
 				ejecutables.memprof=FALSE;
 			}
 			break;
-		case 46:
+		case LTOTALES+LTOTALES+16:
 			aplicacion=TRUE;
-			nodo=buscar_nodo_xml(doc->root,"programas");
+			nodo=buscar_nodo_xml(doc->xmlRootNode,"programas");
 			if (det_prog("gnome-terminal --version 2> /dev/stdout")) {
 				xmlSetProp(nodo,"gnome_terminal","1");
 				ejecutables.gnome_terminal=TRUE;
@@ -656,8 +457,19 @@ void det_autodetectar(xmlDocPtr doc,gboolean crear,guint estado)
 				ejecutables.gnome_terminal=FALSE;
 			}
 			break;
+		case LTOTALES+LTOTALES+17:
+			aplicacion=TRUE;
+			nodo=buscar_nodo_xml(doc->xmlRootNode,"programas");
+			if (det_prog("cvs --version 2> /dev/stdout")) {
+				xmlSetProp(nodo,"cvs","1");
+				ejecutables.cvs=TRUE;
+			} else {
+				xmlSetProp(nodo,"cvs","0");
+				ejecutables.cvs=FALSE;
+			}
+			break;
 	}
-	
+
 	if ((estado>=1) && (!aplicacion)) {
 		g_free(nombre);
 		xmlNodeSetContent(nodo,detectado);
@@ -669,13 +481,16 @@ void det_autodetectar(xmlDocPtr doc,gboolean crear,guint estado)
 	}
 	
 	if ((error) && (estado==ULTIMA_FASE_AUTODETECCION)) {
-		//There are some missing applications
+		 //There are some missing applications
 		programas=g_strdup_printf(_("%s\nThey are needed for DiaSCE to work properly. Install them and make sure they are in your path."),tmp);
 		g_free(tmp);
-		ventana=gnome_error_dialog_parented(programas, GTK_WINDOW(david_ventana));
-		gtk_widget_destroy(ventana_inicio);
-		gnome_dialog_run_and_close(GNOME_DIALOG(ventana));
+		widget = glade_xml_get_widget (david_ventana, "david_ventana");
+		ventana=gnome_error_dialog_parented(programas, GTK_WINDOW(widget));
+		ventana_inicio=glade_xml_get_widget(autodetect_ventana,"autodetect_ventana");
+          gtk_widget_destroy(ventana_inicio);
+          gnome_dialog_run_and_close(GNOME_DIALOG(ventana));
 	} else if (estado == ULTIMA_FASE_AUTODETECCION) {
+		ventana_inicio=glade_xml_get_widget(autodetect_ventana,"autodetect_ventana");
 		gtk_widget_destroy(ventana_inicio);
 	}
 	if (estado==ULTIMA_FASE_AUTODETECCION) {
@@ -785,7 +600,7 @@ gchar *det_inc(gchar *nombre)
 
 /*******************************************************************************
  Devuelve verdadero o falso dependiendo de si un programa puede
- ser ejecutado por diasce o no
+ ser ejecutado por DiaSCE o no
  *******************************************************************************/
 gboolean det_prog(gchar *nombre)
 {
