@@ -1,5 +1,5 @@
 /*
- * diasce
+ * DiaSCE
  * Copyright (C) 2001  Ander Lozano Prez
  *
  * This program is free software; you can redistribute it and/or
@@ -27,10 +27,12 @@
 enum e_pixmaps {PROYECTO=0,CABECERAS,FUENTES,OTROS,ARCHIVO,CLASES,FUNCIONES,UNIONES,ESTRUCURAS,BARIABLES,ENUMERACIONES,TIPOS,MIEMBRO,TOTAL_PIXMAPS};
 
 typedef GdkPixmap* GdkPixmapPtr;
+typedef GdkPixbuf* GdkPixbufPtr;
 
 //*******************************************************************
 
-GdkPixmapPtr pixmaps[TOTAL_PIXMAPS];
+GdkPixbufPtr pixbufs[TOTAL_PIXMAPS];
+GdkPixbuf *pix_marcador;
 
 //*******************************************************************
 
